#
# spec file for package python-pyp
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2020-2021 LISA GmbH, Bingen, Germany
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define skip_python2 1
Name:           python-pyp
Version:        1.3.0
Release:        1.4
Summary:        Python at the shell
License:        MIT
Group:          Development/Libraries/Python
URL:            https://github.com/hauntsaninja/pyp
Source0:        https://github.com/hauntsaninja/pyp/archive/v%{version}.tar.gz#/pyp-%{version}.tar.gz
BuildRequires:  %{python_module astunparse}
BuildRequires:  %{python_module base}
BuildRequires:  %{python_module flit-core}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
# testing requirements
BuildRequires:  bc
BuildRequires:  %{python_module pytest}
BuildRequires:  jq
Requires:       python-astunparse
BuildArch:      noarch
Requires(post): update-alternatives
Requires(postun): update-alternatives
%python_subpackages

%description
Easily run Python at the shell! Magical, but never mysterious.

See README.md or https://github.com/hauntsaninja/pyp for examples.

%prep
%autosetup -p1 -n pyp-%{version}
sed -i '/^#!\//, 1d' pyp.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/pyp
%python_clone -a %{buildroot}%{_bindir}/pypyp
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export PATH=$(pwd):$PATH
%{python_expand ln -sf %{buildroot}%{_bindir}/pyp-%{$python_bin_suffix} pyp
PYTHONPATH=%{buildroot}%{$python_sitelib} py.test-%{$python_bin_suffix} -vv "$( [ -n "${skip_tests_$python}" ] && printf "%s" '-k not ('"${skip_tests_$python}"')')"
}

%post
%python_install_alternative pyp pypyp

%postun
%python_uninstall_alternative pyp

%files %{python_files}
%license LICENSE
%doc *.md
%{python_sitelib}/pyp.py
%{python_sitelib}/pypyp-%{version}*-info
%pycache_only %{python_sitelib}/__pycache__
%python_alternative %{_bindir}/pyp
%python_alternative %{_bindir}/pypyp

%changelog
* Fri Dec 27 2024 Matej Cepl <mcepl@cepl.eu>
- Update to 1.3.0:
  - Add support for Python 3.13
  - Turn missing config file into a warning instead of an error
  - Add support for __pyp_before__ configuration for permanent
    before code
* Mon Dec  9 2024 Matej Cepl <mcepl@cepl.eu>
- Skip failing tests for Python 3.13 (gh#hauntsaninja/pyp#40).
* Tue Mar 26 2024 Markéta Machová <mmachova@suse.com>
- Update to 1.2.0
  * Fix submodule import name detection
  * Add `pypyp` as alternate command line entrypoint
  * Drop support for Python 3.6 and 3.7
  * Testing updates
* Wed Feb 22 2023 Daniel Garcia <daniel.garcia@suse.com>
- Use release from github, the new release was created there
  (gh#hauntsaninja/pyp#33)
* Tue Feb 21 2023 Daniel Garcia <daniel.garcia@suse.com>
- Use release from pypi, the last release it not tagged in github, but
  add a new source with the github repo to get the tests that are not
  in the pypi release. (gh#hauntsaninja/pyp#33)
- Update to 1.1.0:
  * Fix AST construction on Python 3.11
  * Constructed ASTs now have a more convincing end_lineno
  * Test coverage for fallback unparsing, other test improvements
  * Now packaged by flit
- [v1.0.0]
  * Configuration now allows the use of magic variables, effectively
    allowing you to define your own magic variables. See README.md for
    details
  * Explicit printing in used config functions will now disable
    automatic printing
  * Config definitions can now use things defined from wildcard
    imports. Automatic imports now work in config as well
  * Removed s as a magic variable. If you miss it, you can redefine it
    in your config using s = x
  * Implement correct scoping semantics for comprehensions, including
    with assignment expressions
* Thu Sep  9 2021 Hans-Peter Jansen <hpj@urpla.net>
  version 0.3.4:
  - Reduce reconstructed traceback's reliance on CPython
  implementation details
  - Fix automatic print behaviour in edge case interaction with
  scopes
* Fri Sep 25 2020 Hans-Peter Jansen <hpj@urpla.net>
- version 0.3.3: initial build
